@@ -33,7 +33,10 @@ logger = setup_logger(
     "trackme.rest.splk_elastic_sources_admin",
     "trackme_rest_api_splk_elastic_sources_admin.log",
 )
-# Redirect logger.module calls
+# Redirect global logging to use the same handler
+import logging
+logging.getLogger().handlers = logger.handlers
+logging.getLogger().setLevel(logger.level)
 
 
 # import rest handler
@@ -54,9 +57,9 @@ from trackme_libs import (
 import splunklib.client as client
 
 
-class TrackMeHandlerSplkElasticSources_v2(trackme_rest_handler.RESTHandler):
+class TrackMeHandlerSplkElasticSourcesAdmin_v2(trackme_rest_handler.RESTHandler):
     def __init__(self, command_line, command_arg):
-        super(TrackMeHandlerSplkElasticSources_v2, self).__init__(
+        super(TrackMeHandlerSplkElasticSourcesAdmin_v2, self).__init__(
             command_line, command_arg, logger
         )
 
@@ -213,7 +216,7 @@ class TrackMeHandlerSplkElasticSources_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.system_authtoken,
-            timeout=300,
+            timeout=600,
         )
 
         # set loglevel
@@ -476,7 +479,7 @@ class TrackMeHandlerSplkElasticSources_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.system_authtoken,
-            timeout=300,
+            timeout=600,
         )
 
         # set loglevel
@@ -578,7 +581,7 @@ class TrackMeHandlerSplkElasticSources_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.system_authtoken,
-            timeout=300,
+            timeout=600,
         )
         collection = service.kvstore[collection_name]
 
@@ -851,7 +854,7 @@ class TrackMeHandlerSplkElasticSources_v2(trackme_rest_handler.RESTHandler):
                 app="trackme",
                 port=splunkd_port,
                 token=request_info.system_authtoken,
-                timeout=300,
+                timeout=600,
             )
 
             # set loglevel
