@@ -110,7 +110,7 @@ fields = [
         'ui_home_tabs_order',
         required=True,
         encrypted=False,
-        default='dsm,flx,dhm,mhm,wlk,fqm,flip,audit,alerts',
+        default='dsm,cim,flx,dhm,mhm,wlk,fqm,flip,audit,alerts',
         validator=validator.Pattern(
             regex=r"""^[a-zA-Z0-9,]+$""", 
         )
@@ -124,6 +124,24 @@ fields = [
             regex=r"""^[0-9]*$""", 
         )
     ), 
+    field.RestField(
+        'outliers_set_state',
+        required=True,
+        encrypted=False,
+        default='1',
+        validator=validator.Pattern(
+            regex=r"""^(1|0)$""", 
+        )
+    ), 
+    field.RestField(
+        'data_sampling_set_state',
+        required=True,
+        encrypted=False,
+        default='1',
+        validator=validator.Pattern(
+            regex=r"""^(1|0)$""", 
+        )
+    ), 
     field.RestField(
         'data_sampling_obfuscation',
         required=True,
@@ -155,7 +173,7 @@ fields = [
         'mloutliers_allowlist',
         required=True,
         encrypted=False,
-        default='dsm,dhm,flx,wlk,fqm',
+        default='dsm,dhm,flx,wlk,cim,fqm',
         validator=validator.Pattern(
             regex=r"""^[a-zA-Z0-9,]+$""", 
         )
@@ -169,15 +187,6 @@ fields = [
             regex=r"""^(1|0)$""", 
         )
     ), 
-    field.RestField(
-        'monitoring_time_policy',
-        required=True,
-        encrypted=False,
-        default='all_time',
-        validator=validator.Pattern(
-            regex=r"""^.+$""", 
-        )
-    ), 
     field.RestField(
         'splk_feeds_delayed_inspector_24hours_range_min_sec',
         required=True,
@@ -286,6 +295,15 @@ fields = [
             regex=r"""^.+$""", 
         )
     ), 
+    field.RestField(
+        'splk_cim_cmdb_search',
+        required=False,
+        encrypted=False,
+        default='',
+        validator=validator.Pattern(
+            regex=r"""^.+$""", 
+        )
+    ), 
     field.RestField(
         'splk_dsm_tabulator_groupby',
         required=True,
@@ -341,183 +359,12 @@ fields = [
         )
     ), 
     field.RestField(
-        'impact_score_outliers_default',
-        required=False,
+        'splk_cim_tabulator_groupby',
+        required=True,
         encrypted=False,
-        default='36',
+        default='cim_datamodel_name',
         validator=validator.Pattern(
-            regex=r"""^([0-9]|[1-9][0-9]|100)$""", 
-        )
-    ), 
-    field.RestField(
-        'impact_score_dsm_data_sampling_anomaly',
-        required=False,
-        encrypted=False,
-        default='36',
-        validator=validator.Pattern(
-            regex=r"""^([0-9]|[1-9][0-9]|100)$""", 
-        )
-    ), 
-    field.RestField(
-        'impact_score_dsm_delay_threshold_breach',
-        required=False,
-        encrypted=False,
-        default='100',
-        validator=validator.Pattern(
-            regex=r"""^([0-9]|[1-9][0-9]|100)$""", 
-        )
-    ), 
-    field.RestField(
-        'impact_score_dsm_latency_threshold_breach',
-        required=False,
-        encrypted=False,
-        default='48',
-        validator=validator.Pattern(
-            regex=r"""^([0-9]|[1-9][0-9]|100)$""", 
-        )
-    ), 
-    field.RestField(
-        'impact_score_dsm_min_hosts_dcount_breach',
-        required=False,
-        encrypted=False,
-        default='100',
-        validator=validator.Pattern(
-            regex=r"""^([0-9]|[1-9][0-9]|100)$""", 
-        )
-    ), 
-    field.RestField(
-        'impact_score_dsm_future_tolerance_breach',
-        required=False,
-        encrypted=False,
-        default='36',
-        validator=validator.Pattern(
-            regex=r"""^([0-9]|[1-9][0-9]|100)$""", 
-        )
-    ), 
-    field.RestField(
-        'impact_score_dhm_delay_threshold_breach',
-        required=False,
-        encrypted=False,
-        default='100',
-        validator=validator.Pattern(
-            regex=r"""^([0-9]|[1-9][0-9]|100)$""", 
-        )
-    ), 
-    field.RestField(
-        'impact_score_dhm_latency_threshold_breach',
-        required=False,
-        encrypted=False,
-        default='48',
-        validator=validator.Pattern(
-            regex=r"""^([0-9]|[1-9][0-9]|100)$""", 
-        )
-    ), 
-    field.RestField(
-        'impact_score_dhm_future_tolerance_breach',
-        required=False,
-        encrypted=False,
-        default='36',
-        validator=validator.Pattern(
-            regex=r"""^([0-9]|[1-9][0-9]|100)$""", 
-        )
-    ), 
-    field.RestField(
-        'impact_score_mhm_metric_alert',
-        required=False,
-        encrypted=False,
-        default='100',
-        validator=validator.Pattern(
-            regex=r"""^([0-9]|[1-9][0-9]|100)$""", 
-        )
-    ), 
-    field.RestField(
-        'impact_score_mhm_future_tolerance_breach',
-        required=False,
-        encrypted=False,
-        default='36',
-        validator=validator.Pattern(
-            regex=r"""^([0-9]|[1-9][0-9]|100)$""", 
-        )
-    ), 
-    field.RestField(
-        'impact_score_flx_inactive',
-        required=False,
-        encrypted=False,
-        default='100',
-        validator=validator.Pattern(
-            regex=r"""^([0-9]|[1-9][0-9]|100)$""", 
-        )
-    ), 
-    field.RestField(
-        'impact_score_flx_status_not_met',
-        required=False,
-        encrypted=False,
-        default='100',
-        validator=validator.Pattern(
-            regex=r"""^([0-9]|[1-9][0-9]|100)$""", 
-        )
-    ), 
-    field.RestField(
-        'impact_score_fqm_status_not_met',
-        required=False,
-        encrypted=False,
-        default='100',
-        validator=validator.Pattern(
-            regex=r"""^([0-9]|[1-9][0-9]|100)$""", 
-        )
-    ), 
-    field.RestField(
-        'impact_score_wlk_skipping_searches',
-        required=False,
-        encrypted=False,
-        default='100',
-        validator=validator.Pattern(
-            regex=r"""^([0-9]|[1-9][0-9]|100)$""", 
-        )
-    ), 
-    field.RestField(
-        'impact_score_wlk_execution_errors',
-        required=False,
-        encrypted=False,
-        default='100',
-        validator=validator.Pattern(
-            regex=r"""^([0-9]|[1-9][0-9]|100)$""", 
-        )
-    ), 
-    field.RestField(
-        'impact_score_wlk_orphan_search',
-        required=False,
-        encrypted=False,
-        default='100',
-        validator=validator.Pattern(
-            regex=r"""^([0-9]|[1-9][0-9]|100)$""", 
-        )
-    ), 
-    field.RestField(
-        'impact_score_wlk_execution_delayed',
-        required=False,
-        encrypted=False,
-        default='100',
-        validator=validator.Pattern(
-            regex=r"""^([0-9]|[1-9][0-9]|100)$""", 
-        )
-    ), 
-    field.RestField(
-        'impact_score_wlk_out_of_monitoring_times',
-        required=False,
-        encrypted=False,
-        default='100',
-        validator=validator.Pattern(
-            regex=r"""^([0-9]|[1-9][0-9]|100)$""", 
-        )
-    ), 
-    field.RestField(
-        'impact_score_wlk_status_not_met',
-        required=False,
-        encrypted=False,
-        default='100',
-        validator=validator.Pattern(
-            regex=r"""^([0-9]|[1-9][0-9]|100)$""", 
+            regex=r"""^.*$""", 
         )
     )
 ]
